DSAuthProviderMetadata class

Constructors

DSAuthProviderMetadata({required String type, required String region, required String clientId})

Properties

clientId → String
final
hashCode → int
The hash code for this object.
no setterinherited
region → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited