DSAuthProvider class abstract

Interface for all Auth Providers

Constructors

DSAuthProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAccount(String email, String password, {String? displayName}) → Future<void>
Creates a new user account with the given credentials
getCurrentUser() → Future<DSAuthUser>
Retrieves the currently authenticated user
getUser(String userId) → Future<DSAuthUser>
Retrieves a user by their ID
initialize(Map<String, dynamic> config) → Future<void>
Initializes the provider with configuration settings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLoginSuccess(DSAuthUser user) → Future<void>
Lifecycle hooks
onLogout() → Future<void>
Lifecycle hooks
refreshToken(String refreshToken) → Future<String>
Refreshes the current user's token
signIn(String username, String password) → Future<void>
Signs in a user with the given credentials
signOut() → Future<void>
Signs out the current user
toString() → String
A string representation of this object.
inherited
verifyToken([String? token]) → Future<bool>
Retrieves the current user's token

Operators

operator ==(Object other) → bool
The equality operator.
inherited