DSAuthUser class

Standardized User model for consistent structure across providers

Constructors

DSAuthUser({required String id, required String email, required String displayName, Map<String, dynamic>? customAttributes})
Creates a new user instance

Properties

customAttributes → Map<String, dynamic>?
Custom attributes for user
final
displayName → String
User's display name
final
email → String
User's email address
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique user ID
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited